import UploadFile from '@/components/UploadFile';
import { useAjax } from '@/Hook/useAjax';
import {
  apiShortBookParagraph,
  apiShortBookParagraphAdd,
  apiShortBookParagraphDel,
  apiShortBookParagraphEdit,
  apiShortBookParagraphList,
} from '@/services/book/shortbookList';
import { PlusCircleOutlined } from '@ant-design/icons';
import { ActionType, BetaSchemaForm, ProFormInstance, ProTable } from '@ant-design/pro-components';
import { Button, Drawer, message } from 'antd';
import { useRef, useState } from 'react';
import { childrenColumns } from './tableConfig';
type DataItem = {
  name: string;
  state: string;
};
type Props = {
  data: any;
  onClose: (v: any) => void;
};
const Page: React.FC<Props> = (props) => {
  let { data, onClose } = props;
  let [open, setOpen] = useState<any>(null); //新建弹窗
  const [uploadOpen, setUploadOpen] = useState(false);
  let [editValues, setEditValues] = useState<any>({});
  // ======================API=======================
  let ShortBookParagraphList = useAjax((params) => apiShortBookParagraphList(params), {
    type: 'table',
  }); //小说段落列表
  let ShortBookParagraphAdd = useAjax((params) => apiShortBookParagraphAdd(params)); //小说段落新增
  let ShortBookParagraphEdit = useAjax((params) => apiShortBookParagraphEdit(params)); //小说段落编辑
  let ShortBookParagraphDel = useAjax((params) => apiShortBookParagraphDel(params)); //小说段落删除
  let ShortBookParagraph = useAjax((id) => apiShortBookParagraph(id)); //查询单个段落
  const formRef = useRef<ProFormInstance>();
  const actionRef = useRef<ActionType>();

  // 删除or批量删除
  const del = (id: any) => {
    ShortBookParagraphDel.run(id).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('删除成功');
      }
    });
  };
  // 提交表单
  const submit = async (values: any) => {
    let api = editValues?.id ? ShortBookParagraphEdit : ShortBookParagraphAdd;
    if (editValues?.id) {
      values.id = editValues?.id;
    }
    values.bookId = data.id;
    api.run(values).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('操作成功!');
        closeForm(false);
      }
    });
  };
  // 关闭表单弹窗和重置表单内容
  const closeForm = (b: boolean, values?: any) => {
    if (!b) {
      setEditValues({});
      formRef?.current?.resetFields?.();
      setOpen(b);
    } else {
      setEditValues(values);
      ShortBookParagraph.run(values.id).then((res: any) => {
        if (res.code === 200) {
          formRef?.current?.setFieldsValue(res.data);
        }
      });

      setOpen(b);
    }
  };

  return (
    <Drawer
      open={data?.id}
      placement="right"
      onClose={() => {
        onClose({});
      }}
      width={'75%'}
      footer={null}
      destroyOnClose={true}
      closeIcon={false}
    >
      <ProTable<any, any>
        headerTitle={'《' + data?.bookName + '》段落管理'}
        actionRef={actionRef}
        rowKey={(r) => r.id}
        search={false}
        params={{ bookId: data?.id }}
        scroll={{ x: 'auto' }}
        request={async (params) => {
          if (params.bookId) {
            return await ShortBookParagraphList.run(params);
          }
        }}
        toolBarRender={() => {
          return [
            <Button
              type="primary"
              onClick={() => {
                setOpen(true);
              }}
            >
              <PlusCircleOutlined />
              新增段落
            </Button>,
            <Button
              type="primary"
              onClick={() => {
                setUploadOpen(true);
              }}
            >
              <PlusCircleOutlined />
              上传段落
            </Button>,
          ];
        }}
        columns={childrenColumns({ del, closeForm })}
      />
      {/* 新增段落 */}
      <BetaSchemaForm<DataItem>
        layout="horizontal"
        title={!editValues?.id ? '新增段落' : '编辑段落'}
        formRef={formRef}
        open={open}
        onOpenChange={(b) => {
          !b && closeForm(b);
        }}
        layoutType={'DrawerForm'}
        rowProps={{
          gutter: [16, 16],
        }}
        labelCol={{ span: 3 }}
        colProps={{ span: 23 }}
        grid={true}
        onFinish={submit}
        columns={[
          {
            title: '段落号',
            dataIndex: 'paragraphNo',
            valueType: 'digit',
            formItemProps: {
              style: { marginBottom: 10 },
              rules: [
                {
                  required: true,
                  message: '此项为必填项',
                },
              ],
            },
          },
          {
            title: '段落内容',
            dataIndex: 'content',
            valueType: 'textarea',
            fieldProps: {
              rows: 46,
            },
            formItemProps: {
              style: { marginBottom: 10 },
              rules: [
                {
                  required: true,
                  message: '此项为必填项',
                },
              ],
            },
          },
        ]}
        loading={ShortBookParagraphAdd?.loading || ShortBookParagraphEdit?.loading}
      />
      {/* 上传段落 */}
      <Drawer
        title={`上传《${data?.bookName}》段落`}
        placement="right"
        width={'39%'}
        closable={false}
        onClose={() => {
          setUploadOpen(false);
        }}
        open={uploadOpen}
      >
        <UploadFile
          type="short"
          bookId={data?.id}
          refresh={actionRef?.current?.reload}
          open={uploadOpen}
        />
      </Drawer>
    </Drawer>
  );
};
export default Page;
