import { api } from '@/services/api';
import { request } from '@umijs/max';

/**
 * 小说修改
 * @param data
 * @returns
 */
export async function apiBookContentShortBookInfoEdit(params: any) {
  let { id, ...data } = params;
  return request(api + `/bookContent/admin/shortBookInfo/${id}`, {
    method: 'PUT',
    data,
  });
}
/**
 * 小说新增
 * 
 * @param   "workDirection" 作品方向;0-男频 1-女频
  @param "categoryId" 类别ID
 @param "labelIds" 标签
 @param "picUrl" 封面地址，多个用,拼接
 @param "bookName" 小说名
 @param "authorId" 作者ID
  @param"bookDesc" 书籍描述
 @param "source" 来源（UPLOAD：管理员上传、CREATOR：创作者）
 @param "bookStatus" 书籍状态;0-连载中 1-已完结
 @param "shelveStatus" 上下架状态;0-上架 1-下架
@param  "vipFree" vip 是否免费阅读;0-否，1是
  @param"paymentType" 付费类型：0-免费 1-按千字收费 2-整本收费
@param  "paymentMoney" 付费金额（分）
 */
export async function apiBookContentShortBookInfoAdd(data: any) {
  return request(api + '/bookContent/admin/shortBookInfo', {
    method: 'POST',
    data,
  });
}
/**
 * 小说批量上下架
 * @param data
 * @returns
 */
export async function apiBookContentShortBookInfoBatch(data: any) {
  let { shelve, ids } = data;
  return request(api + `/bookContent/admin/shortBookInfo/shelve/batch?shelve=${shelve}`, {
    method: 'POST',
    data: ids,
  });
}
/**
 * 小说删除
 * @param data
 * @returns
 */
export async function apiBookContentShortBookInfoDel(id: any) {
  return request(api + `/bookContent/admin/shortBookInfo/remove/one/${id}`, {
    method: 'DELETE',
  });
}
/**
 * 小说批量删除
 * @param data
 * @returns
 */
export async function apiBookContentShortBookInfoDels(params: any[]) {
  return request(api + `/bookContent/admin/shortBookInfo/remove/batch`, {
    method: 'DELETE',
    data: params,
  });
}
/**
 * 小说列表
 * @param workDirection 频道
 * @param categoryId 分类ID
 * @param labelId 标签ID
 * @param bookName 书籍名称
 * @param authorName 作者名称
 * @param startWordCount 最少字数
 * @param endWordCount 最大字数
 * @param bookStatus 书籍状态;0-连载中 1-已完结
 * @param shelveStatus 上下架状态;0-上架 1-下架
 * @param paymentType  付费类型：0-免费 1-按千字收费 2-整本收费
 * @param vipFree vip 是否免费阅读;0-否 1是
 * @returns
 */
export async function apiBookContentShortBookInfoList(params: number) {
  return request(api + `/bookContent/admin/shortBookInfo/list`, {
    method: 'GET',
    params,
  });
}

// =================================段落===========================
/**
 * 小说段落列表
 * @param bookId
 * @param sort
 * @param isPayment
 * */
export async function apiShortBookParagraphList(params: any) {
  return request(api + `/bookContent/admin/shortBookParagraph/list`, {
    method: 'GET',
    params,
  });
}
/**
 * 小说段落列表
 * @param bookId
 * @param sort
 * @param isPayment
 * */
export async function apiShortBookParagraph(id: any) {
  return request(api + `/bookContent/admin/shortBookParagraph/one/${id}`, {
    method: 'GET',
  });
}
/**
 * 段落新增
 *
 * @param   bookId 小说id
 * @param   paragraphNo 段落号
 * @param   paragraphNo 小说段落内容
 * @param   beginPayment 是否是开始收费段落
 */
export async function apiShortBookParagraphAdd(data: any) {
  return request(api + '/bookContent/admin/shortBookParagraph', {
    method: 'POST',
    data,
  });
}
/**
 * 段落修改
 * @param id 段落ID
 * @param   bookId 小说id
 * @param   paragraphNo 段落号
 * @param   paragraphNo 小说段落内容
 * @param   beginPayment 是否是开始收费段落
 */
export async function apiShortBookParagraphEdit(params: any) {
  let { id, ...data } = params;
  return request(api + `/bookContent/admin/shortBookParagraph/${id}`, {
    method: 'PUT',
    data,
  });
}

/**
 * 段落删除
 * @param id  段落ID
 */
export async function apiShortBookParagraphDel(id: any) {
  return request(api + `/bookContent/admin/shortBookParagraph/remove/one/${id}`, {
    method: 'DELETE',
  });
}

/**
 * 上传段落
 *
 * @param   bookId 小说id
 * @param   file
 */
export async function apiShortBookUploadShortBook(data: any) {
  return request(api + '/bookContent/admin/shortBookInfo/uploadShortBook', {
    method: 'POST',
    data,
  });
}

/**
 * 获取短篇小说内容
 *
 * @param   bookId 小说id
 * @param   pageNum
 * @param   pageSize
 */
export async function apiShortBookGetInfo(params: any) {
  return request(api + '/bookContent/admin/shortBookInfo/getInfo', {
    method: 'GET',
    params,
  });
}
